function [valuepde,valuemc]=bondCIR
% In this exercise we compute the bond price at time 0 in a CIR shortrate model dr_t= (a-b
% r_t) dt + \sigma \sqrt(r_t) dW_t
tic
%% parameter input
% horizon
T=10;
% sample size
Nsimu=10^5;
Nplot=Nsimu;
% grid points
M=10^3;
% volatility
sigma=0.04;
a=0.0052;
b=0.0447;
% initial value = r_0
r0=0.08;
% time step
dt= T/M;

%% Analytical approach
gamma = sqrt(b^2+2*sigma^2);
AT= -2*a/(sigma^2)*log(2*gamma*exp((gamma+b)*T/2)/((gamma+b)*(exp(gamma*T)-1)+2*gamma));
BT= 2*(exp(gamma*T)-1)/((gamma+b)*(exp(gamma*T)-1)+2*gamma);
valuepde=exp(-AT-BT*r0);

%% Monte Carlo approach
% BM
BM = [zeros(1,Nplot);sqrt(T/M)*cumsum(randn(M,Nplot))];
CIR = [r0*ones(1,Nplot);zeros(M,Nplot)];
% Euler Maruyama Scheme
for i =1:M
    CIR(i+1,:)=CIR(i,:)+(a-b*CIR(i,:))*dt+ sigma.*sqrt(CIR(i,:)).*(BM(i+1,:)-BM(i,:));
end

mean(CIR(end,:))
var(CIR(end,:))

integral = zeros(1,Nsimu);
intgrid= 0:dt:T;
for j= 1:Nsimu
    % use trapezoidal rule
    integral(j)= trapz(intgrid,CIR(:,j));
end
% take the expectation
valuemc= mean(exp(-integral));
toc